@@ -152,6 +152,7 @@ describe 'horizon' do
           "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')",
           'CSRF_COOKIE_SECURE = True',
           'SESSION_COOKIE_SECURE = True',
+          'SESSION_COOKIE_HTTPONLY = True',
           "  'identity': 2.0,",
           "OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT = True",
           "OPENSTACK_KEYSTONE_DEFAULT_DOMAIN = 'domain.tld'",
@@ -764,12 +765,30 @@ describe 'horizon' do
             }
           end
         when 'RedHat'
-          { :config_file      => '/etc/openstack-dashboard/local_settings',
-            :package_name     => 'openstack-dashboard',
-            :root_url         => '/dashboard',
-            :root_path        => '/usr/share/openstack-dashboard',
-            :memcache_package => 'python-memcached',
-          }
+          if facts[:operatingsystem] == 'Fedora'
+            { :config_file      => '/etc/openstack-dashboard/local_settings',
+              :package_name     => 'openstack-dashboard',
+              :root_url         => '/dashboard',
+              :root_path        => '/usr/share/openstack-dashboard',
+              :memcache_package => 'python3-memcached',
+            }
+          else
+            if facts[:operatingsystemmajrelease] > '7'
+              { :config_file      => '/etc/openstack-dashboard/local_settings',
+                :package_name     => 'openstack-dashboard',
+                :root_url         => '/dashboard',
+                :root_path        => '/usr/share/openstack-dashboard',
+                :memcache_package => 'python3-memcached',
+              }
+            else
+              { :config_file      => '/etc/openstack-dashboard/local_settings',
+                :package_name     => 'openstack-dashboard',
+                :root_url         => '/dashboard',
+                :root_path        => '/usr/share/openstack-dashboard',
+                :memcache_package => 'python-memcached',
+              }
+            end
+          end
         end
       end
 
